@@ -25,8 +25,9 @@ app = FastAPI()
 
 
 @app.post('/')
-def read_root(kwargs:dict):
+def read_root(kwargs:dict, a:int=0):
     print(kwargs)
+    print(type(a), a)
     return kwargs
 
 @app.post('/')
